@@ -31,10 +31,6 @@ class TarantoolCache(BaseCache):
         return self._extract_value(value)
 
     def get_backend_timeout(self, timeout=DEFAULT_TIMEOUT):
-        """
-        Memcached deals with long (> 30 days) timeouts in a special
-        way. Call this function to obtain a safe value for your timeout.
-        """
         if timeout == DEFAULT_TIMEOUT:
             timeout = self.default_timeout
 
@@ -45,15 +41,6 @@ class TarantoolCache(BaseCache):
             # Other cache backends treat 0 as set-and-expire. To achieve this
             # in memcache backends, a negative timeout must be passed.
             timeout = -1
-
-        if timeout > 2592000:  # 60*60*24*30, 30 days
-            # See http://code.google.com/p/memcached/wiki/FAQ
-            # "You can set expire times up to 30 days in the future. After that
-            # memcached interprets it as a date, and will expire the item after
-            # said date. This is a simple (but obscure) mechanic."
-            #
-            # This means that we have to switch to absolute timestamps.
-            timeout += int(time.time())
         return str(timeout)
 
     def make_key(self, key, version=None):
